Common objects for XML serialization base (sarpy.io.xml.base)
=============================================================

.. automodule:: sarpy.io.xml.base
    :members:
    :show-inheritance:
    :inherited-members:
